import { Modal, Button, Form } from "react-bootstrap"
import { Restaurant } from "../../../../types";
import { getRestaurantName } from "../../enums";
import { useState } from "react";

type Props = {
    isOpen: boolean,
    onClose: () => void,
    onSubmit: (restaurants: Restaurant[]) => void,
}

/** Modální dialog pro přenačtení menu jednotlivých podniků. */
export default function RefreshMenuModal({ isOpen, onClose, onSubmit }: Readonly<Props>) {

    const [restaurants, setRestaurants] = useState<Restaurant[]>([]);

    const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        if (e.currentTarget.checked) {
            setRestaurants([...restaurants, e.currentTarget.value as Restaurant]);
        } else {
            setRestaurants(restaurants.filter(restaurant => restaurant !== e.currentTarget.value as Restaurant));
        }
    }

    return <Modal show={isOpen} onHide={onClose} size="lg">
        <Modal.Header closeButton>
            <Modal.Title>
                Vyberte podniky k přenačtení menu
                <p style={{ fontSize: '12px' }}>Menu lze přenačíst nejdříve 15 minut od poslední aktualizace</p>
            </Modal.Title>
        </Modal.Header>
        <Modal.Body>
            {(Object.keys(Restaurant) as Array<keyof typeof Restaurant>).map(key => {
                return <Form.Check
                    key={key}
                    type='checkbox'
                    id={key}
                    label={getRestaurantName(key as Restaurant)}
                    onChange={handleChange}
                    value={key}
                />
            })}
        </Modal.Body>
        <Modal.Footer>
            <Button variant="primary" onClick={() => onSubmit(restaurants)} disabled={restaurants.length === 0}>
                Přenačíst
            </Button>
            <Button variant="secondary" onClick={onClose}>
                Zrušit
            </Button>
        </Modal.Footer>
    </Modal>
}